==> v1.7.8.zip: bypass-paywalls-chrome/README.md <==
<p align="center">
  <img src="https://github.com/iamadamdev/bypass-paywalls-chrome/blob/master/src/icons/bypass.png" width="75" height="75"/>
</p>

<h1 align="center">Bypass Paywalls</h1>

*Bypass Paywalls is a web browser extension to help bypass paywalls for selected sites.*

### Installation Instructions
**Google Chrome** (Custom sites supported)
1. Download this repo as a [ZIP file from GitHub](https://github.com/iamadamdev/bypass-paywalls-chrome/archive/master.zip).
1. Unzip the file and you should have a folder named `bypass-paywalls-chrome-master`.
1. In Chrome go to the extensions page (`chrome://extensions`).
1. Enable Developer Mode.
1. Drag the `bypass-paywalls-chrome-master` folder anywhere on the page to import it (do not delete the folder afterwards).

**Mozilla Firefox** (Custom sites not supported)
* [Download and install the latest version](https://github.com/iamadamdev/bypass-paywalls-chrome/releases/latest/download/bypass-paywalls-firefox.xpi)

**Notes**
* Every time you open Chrome it may warn you about running extensions in developer mode, just click &#10005; to keep the extension enabled.
* You will be logged out for any site you have checked.
* This extension works best alongside the adblocker uBlock Origin.
* On the Firefox version automatic updates are enabled.

### Bypass the following sites' paywalls with this extension:

[Adweek](https://www.adweek.com)\
[Algemeen Dagblad](https://www.ad.nl)\
[American Banker](https://www.americanbanker.com)\
[Baltimore Sun](https://www.baltimoresun.com)\
[Barron's](https://www.barrons.com)\
[Bloomberg Quint](https://www.bloombergquint.com)\
[Bloomberg](https://www.bloomberg.com)\
[BN De Stem](https://www.bndestem.nl)\
[Brabants Dagblad](https://www.bd.nl)\
[Brisbane Times](https://www.brisbanetimes.com.au)\
[Business Insider](https://www.businessinsider.com)\
[Caixin](https://www.caixinglobal.com)\
[Central Western Daily](https://www.centralwesterndaily.com.au)\
[Chemical & Engineering News](https://cen.acs.org)\
[Chicago Tribune](https://www.chicagotribune.com)\
[Corriere Della Sera](https://www.corriere.it)\
[Crain's Chicago Business](https://www.chicagobusiness.com)\
[Daily Press](https://www.dailypress.com)\
[De Gelderlander](https://www.gelderlander.nl)\
[De Groene Amsterdammer](https://www.groene.nl)\
[De Stentor](https://www.destentor.nl)\
[De Tijd](https://www.tijd.be)\
[De Volkskrant](https://www.volkskrant.nl)\
[DELFI](https://www.delfi.ee)\
[DeMorgen](https://www.demorgen.be)\
[Denver Post](https://www.denverpost.com)\
[Diario Financiero](https://www.df.cl)\
[Domani](https://www.editorialedomani.it/)\
[Dynamed Plus](https://www.dynamed.com)\
[Eindhovens Dagblad](https://www.ed.nl)\
[El Mercurio](https://www.elmercurio.com)\
[El Pais](https://www.elpais.com/)\
[Elu24](https://www.elu24.ee)\
[Encyclopedia Britannica](https://www.britannica.com)\
[Estadão](https://www.estadao.com.br)\
[Examiner](https://www.examiner.com.au)\
[Financial News](https://www.fnlondon.com)\
[Financial Post](https://www.financialpost.com)\
[Financial Times](https://www.ft.com)\
[First Things](https://www.firstthings.com)\
[Foreign Policy](https://www.foreignpolicy.com)\
[Fortune](https://www.fortune.com)\
[Genomeweb](https://www.genomeweb.com)\
[Glassdoor](https://www.glassdoor.com)\
[Globes](https://www.globes.co.il)\
[Grubstreet](https://www.grubstreet.com)\
[Haaretz.co.il](https://www.haaretz.co.il)\
[Haaretz.com](https://www.haaretz.com)\
[Handelsblatt](https://www.handelsblatt.com)\
[Harper's Magazine](https://harpers.org)\
[Hartford Courant](https://www.courant.com)\
[Harvard Business Review](https://www.hbr.org)\
[Herald Sun](https://www.heraldsun.com.au)\
[Het Financieel Dagblad](https://fd.nl)\
[History Extra](https://www.historyextra.com)\
[Humo](https://www.humo.be)\
[Il Manifesto](https://www.ilmanifesto.it)\
[Inc.com](https://www.inc.com)\
[Interest.co.nz](https://www.interest.co.nz)\
[Investors Chronicle](https://www.investorschronicle.co.uk)
[L'Écho](https://www.lecho.be)\
[L.A. Business Journal](https://labusinessjournal.com)\
[La Nación](https://www.lanacion.com.ar)\
[La Repubblica](https://www.repubblica.it)\
[La Stampa](https://www.lastampa.it)\
[La Tercera](https://www.latercera.com)\
[Le Devoir](https://www.ledevoir.com)\
[Le Parisien](http://www.leparisien.fr)\
[Les Échos](https://www.lesechos.fr)\
[Loeb Classical Library](https://www.loebclassics.com)\
[London Review of Books](https://www.lrb.co.uk)\
[Los Angeles Times](https://www.latimes.com)\
[MIT Sloan Management Review](https://sloanreview.mit.edu)\
[MIT Technology Review](https://www.technologyreview.com)\
[Medium](https://www.medium.com)\
[Medscape](https://www.medscape.com)\
[Mexicon News Daily](https://mexiconewsdaily.com)\
[Mountain View Voice](https://www.mv-voice.com)\
[New York Daily News](https://www.nydailynews.com/)\
[NRC Handelsblad](https://www.nrc.nl)\
[NT News](https://www.ntnews.com.au)\
[National Post](https://www.nationalpost.com)\
[Neue Zürcher Zeitung](https://www.nzz.ch)\
[New York Magazine](https://www.nymag.com)\
[New Zealand Herald](https://www.nzherald.co.nz)\
[Nikkei Asian Review](https://asia.nikkei.com)\
[Orange County Register](https://www.ocregister.com)\
[Orlando Sentinel](https://www.orlandosentinel.com)\
[PZC](https://www.pzc.nl)\
[Palo Alto Online](https://www.paloaltoonline.com)\
[Parool](https://www.parool.nl)\
[Postimees](https://www.postimees.ee)\
[Quartz](https://qz.com)\
[Quora](https://www.quora.com)\
[Republic.ru](https://republic.ru)\
[San Diego Union Tribune](https://www.sandiegouniontribune.com)\
[San Francisco Chronicle](https://www.sfchronicle.com)\
[Scientific American](https://www.scientificamerican.com)\
[Seeking Alpha](https://seekingalpha.com)\
[Slate](https://slate.com)\
[SOFREP](https://sofrep.com)\
[Statista](https://www.statista.com)\
[Star Tribune](https://www.startribune.com)\
[Stuff](https://www.stuff.co.nz)\
[SunSentinel](https://www.sun-sentinel.com)\
[Tech in Asia](https://www.techinasia.com)\
[Telegraaf](https://www.telegraaf.nl)\
[The Advertiser](https://www.adelaidenow.com.au)\
[The Advocate](https://www.theadvocate.com.au)\
[The Age](https://www.theage.com.au)\
[The American Interest](https://www.the-american-interest.com)\
[The Atlantic](https://www.theatlantic.com)\
[The Australian Financial Review](https://www.afr.com)\
[The Australian](https://www.theaustralian.com.au)\
[The Business Journals](https://www.bizjournals.com)\
[The Canberra Times](https://www.canberratimes.com.au)\
[The Courier](https://www.thecourier.com.au)\
[The Courier Mail](https://www.couriermail.com.au)\
[The Cut](https://www.thecut.com)\
[The Daily Telegraph](https://www.dailytelegraph.com.au)\
[The Diplomat](https://www.thediplomat.com)\
[The Economist](https://www.economist.com)\
[The Globe and Mail](https://www.theglobeandmail.com)\
[The Herald](https://www.theherald.com.au)\
[The Hindu](https://www.thehindu.com)\
[The Irish Times](https://www.irishtimes.com)\
[The Japan Times](https://www.japantimes.co.jp)\
[The Kansas City Star](https://www.kansascity.com)\
[The Mercury News](https://www.mercurynews.com)\
[The Mercury Tasmania](https://www.themercury.com.au)\
[The Morning Call](https://www.mcall.com)\
[The Nation](https://www.thenation.com)\
[The National](https://www.thenational.scot)\
[The New Statesman](https://www.newstatesman.com)\
[The New York Times](https://www.nytimes.com)\
[The New Yorker](https://www.newyorker.com)\
[The News-Gazette](https://www.news-gazette.com)\
[The Philadelphia Inquirer](https://www.inquirer.com)\
[The Saturday Paper](https://www.thesaturdaypaper.com.au)\
[The Seattle Times](https://www.seattletimes.com)\
[The Spectator Australia](https://www.spectator.com.au)\
[The Spectator](https://www.spectator.co.uk)\
[The Sydney Morning Herald](https://www.smh.com.au)\
[The Telegraph](https://www.telegraph.co.uk)\
[The Times](https://www.thetimes.co.uk)\
[The Toronto Star](https://www.thestar.com)\
[The Wall Street Journal](https://www.wsj.com)\
[The Washington Post](https://www.washingtonpost.com)\
[The Wrap](https://www.thewrap.com)\
[TheMarker](https://www.themarker.com)\
[Times Literary Supplement](https://www.the-tls.co.uk)\
[Towards Data Science](https://www.towardsdatascience.com)\
[Trouw](https://www.trouw.nl)\
[Tubantia](https://www.tubantia.nl)\
[Vanity Fair](https://www.vanityfair.com)\
[Vrij Nederland](https://www.vn.nl)\
[Vulture](https://www.vulture.com/)\
[Winston-Salem Journal](https://journalnow.com)\
[Wired](https://www.wired.com)\
[World Politics Review](https://www.worldpoliticsreview.com)

### Sites with limited number of free articles
The free article limit can normally be bypassed by removing cookies for the site.*

Install the Cookie Remover extension [for Google Chrome](https://chrome.google.com/webstore/detail/cookie-remover/kcgpggonjhmeaejebeoeomdlohicfhce) or [for Mozilla Firefox](https://addons.mozilla.org/en-US/firefox/addon/cookie-remover/). Please rate it 5 stars if you find it useful.


When coming across a paywall click the cookie icon to remove the cookies then refresh the page.

_*May not always succeed_

### New site requests
Only large or major sites will be considered. Usually premium articles cannot be bypassed as they are behind a hard paywall.

1. Install the uBlock Origin extension if it hasn't been installed already. See if you are still getting a paywall.
2. Check if using Cookie Remover ([Google Chrome version](https://chrome.google.com/webstore/detail/cookie-remover/kcgpggonjhmeaejebeoeomdlohicfhce) or [Mozilla Firefox version](https://addons.mozilla.org/en-US/firefox/addon/cookie-remover/)) can bypass the paywall. If not, continue to the next step.
3. First search [Issues](https://github.com/iamadamdev/bypass-paywalls-chrome/issues) to see if the site has been requested already.
4. Visit an article on the site you want to bypass the paywall for and copy the article title.
5. Open up a new incognito window (Ctrl+Shift+N on Chrome) or Private window (Ctrl+Shift+P on Firefox), and paste the article title into Google.
6. Click on the same article from the Google search results page.
7. If it loads without a paywall you can [submit a request](https://github.com/iamadamdev/bypass-paywalls-chrome/issues/new/choose) and replace the entire template text with the word "Confirmed". Otherwise please do not submit an issue as this extension cannot bypass it either.

### Troubleshooting
* This extension works best alongside uBlock Origin [for Google Chrome](https://chrome.google.com/webstore/detail/ublock-origin/cjpalhdlnbpafiamejdnhcphjbkeiagm) or [for Mozilla Firefox](https://addons.mozilla.org/en-US/firefox/addon/ublock-origin/).
* If a site doesn't work, try turning off uBlock and refreshing.
* Try clearing [cookies](https://chrome.google.com/webstore/detail/cookie-remover/kcgpggonjhmeaejebeoeomdlohicfhce).
* Make sure you're running the latest version of Bypass Paywalls.
* If a site is having problems try unchecking "\*General Paywall Bypass\*" in Options.
* If none of these work, you can submit an issue [here](https://github.com/iamadamdev/bypass-paywalls-chrome/issues/new/choose).

### Contributing - Pull Requests
PRs are welcome. 
1. If making a PR to add a new site, confirm your changes actually bypass the paywall.
2. At a minimum these files need to be updated: `README.md`, `manifest-ff.json`, `src/js/sites.js`, and possibly `src/js/background.js`, and/or `src/js/contentScript.js`.
3. Follow existing code-style and use camelCase.
4. Use [JavaScript Semi-Standard Style linter](https://github.com/standard/semistandard). Don't need to follow it exactly. There will be some errors (e.g., do not use it on `sites.js`).

### Show your support
* Follow me on Twitter [@iamadamdev](https://twitter.com/iamadamdev) for updates.
* I do not ask for donations, all I ask is that you star this repo.

### Disclaimer
* This software is provided for educational purposes only.
* This software is provided "AS IS", without warranty of any kind, express or
implied, including but not limited to the warranties of merchantability,
fitness for a particular purpose and noninfringement. in no event shall the
authors or copyright holders be liable for any claim, damages or other
liability, whether in an action of contract, tort or otherwise, arising from,
out of or in connection with the software or the use or other dealings in the
software.

==> v1.7.9.zip: bypass-paywalls-chrome/README.md <==
<p align="center">
  <img src="https://github.com/iamadamdev/bypass-paywalls-chrome/blob/master/src/icons/bypass.png" width="75" height="75"/>
</p>

<h1 align="center">Bypass Paywalls</h1>

*Bypass Paywalls is a web browser extension to help bypass paywalls for selected sites.*

### Installation Instructions
**Google Chrome / Microsoft Edge** (Custom sites supported)
1. Download this repo as a [ZIP file from GitHub](https://github.com/iamadamdev/bypass-paywalls-chrome/archive/master.zip).
1. Unzip the file and you should have a folder named `bypass-paywalls-chrome-master`.
1. In Chrome/Edge go to the extensions page (`chrome://extensions` or `edge://extensions`).
1. Enable Developer Mode.
1. Drag the `bypass-paywalls-chrome-master` folder anywhere on the page to import it (do not delete the folder afterwards).

**Mozilla Firefox** (Custom sites not supported)
* [Download the latest version from the Firefox add-ons store](https://addons.mozilla.org/en-US/firefox/addon/bypass-paywalls-firefox/)

**Notes**
* Every time you open Chrome it may warn you about running extensions in developer mode, just click &#10005; to keep the extension enabled.
* You will be logged out for any site you have checked.
* This extension works best alongside the adblocker uBlock Origin.
* The Firefox version supports automatic updates.

### Bypass the following sites' paywalls with this extension:

[Adweek](https://www.adweek.com)\
[Algemeen Dagblad](https://www.ad.nl)\
[American Banker](https://www.americanbanker.com)\
[Ámbito](https://www.ambito.com/)\
[Baltimore Sun](https://www.baltimoresun.com)\
[Barron's](https://www.barrons.com)\
[Bloomberg Quint](https://www.bloombergquint.com)\
[Bloomberg](https://www.bloomberg.com)\
[BN De Stem](https://www.bndestem.nl)\
[Brabants Dagblad](https://www.bd.nl)\
[Brisbane Times](https://www.brisbanetimes.com.au)\
[Business Insider](https://www.businessinsider.com)\
[Caixin](https://www.caixinglobal.com)\
[Central Western Daily](https://www.centralwesterndaily.com.au)\
[Chemical & Engineering News](https://cen.acs.org)\
[Chicago Tribune](https://www.chicagotribune.com)\
[Corriere Della Sera](https://www.corriere.it)\
[Crain's Chicago Business](https://www.chicagobusiness.com)\
[Daily Press](https://www.dailypress.com)\
[De Gelderlander](https://www.gelderlander.nl)\
[De Groene Amsterdammer](https://www.groene.nl)\
[De Stentor](https://www.destentor.nl)\
[De Speld](https://speld.nl)\
[De Tijd](https://www.tijd.be)\
[De Volkskrant](https://www.volkskrant.nl)\
[DELFI](https://www.delfi.ee)\
[DeMorgen](https://www.demorgen.be)\
[Denver Post](https://www.denverpost.com)\
[Diario Financiero](https://www.df.cl)\
[Domani](https://www.editorialedomani.it/)\
[Dynamed Plus](https://www.dynamed.com)\
[Eindhovens Dagblad](https://www.ed.nl)\
[El Mercurio](https://www.elmercurio.com)\
[El Pais](https://www.elpais.com/)\
[El Periodico](https://www.elperiodico.com/)\
[Elu24](https://www.elu24.ee)\
[Encyclopedia Britannica](https://www.britannica.com)\
[Estadão](https://www.estadao.com.br)\
[Examiner](https://www.examiner.com.au)\
[Financial News](https://www.fnlondon.com)\
[Financial Post](https://www.financialpost.com)\
[Financial Times](https://www.ft.com)\
[First Things](https://www.firstthings.com)\
[Foreign Policy](https://www.foreignpolicy.com)\
[Fortune](https://www.fortune.com)\
[Genomeweb](https://www.genomeweb.com)\
[Glassdoor](https://www.glassdoor.com)\
[Globes](https://www.globes.co.il)\
[Grubstreet](https://www.grubstreet.com)\
[Haaretz.co.il](https://www.haaretz.co.il)\
[Haaretz.com](https://www.haaretz.com)\
[Handelsblatt](https://www.handelsblatt.com)\
[Harper's Magazine](https://harpers.org)\
[Hartford Courant](https://www.courant.com)\
[Harvard Business Review](https://www.hbr.org)\
[Herald Sun](https://www.heraldsun.com.au)\
[Het Financieel Dagblad](https://fd.nl)\
[History Extra](https://www.historyextra.com)\
[Humo](https://www.humo.be)\
[Il Manifesto](https://www.ilmanifesto.it)\
[Inc.com](https://www.inc.com)\
[Interest.co.nz](https://www.interest.co.nz)\
[Investors Chronicle](https://www.investorschronicle.co.uk)
[L'Écho](https://www.lecho.be)\
[L.A. Business Journal](https://labusinessjournal.com)\
[La Nación](https://www.lanacion.com.ar)\
[La Repubblica](https://www.repubblica.it)\
[La Stampa](https://www.lastampa.it)\
[La Tercera](https://www.latercera.com)\
[La Voix du Nord](https://www.lavoixdunord.fr/)\
[Le Devoir](https://www.ledevoir.com)\
[Le Parisien](http://www.leparisien.fr)\
[Les Échos](https://www.lesechos.fr)\
[Loeb Classical Library](https://www.loebclassics.com)\
[London Review of Books](https://www.lrb.co.uk)\
[Los Angeles Times](https://www.latimes.com)\
[MIT Sloan Management Review](https://sloanreview.mit.edu)\
[MIT Technology Review](https://www.technologyreview.com)\
[Medium](https://www.medium.com)\
[Medscape](https://www.medscape.com)\
[Mexicon News Daily](https://mexiconewsdaily.com)\
[Mountain View Voice](https://www.mv-voice.com)\
[New York Daily News](https://www.nydailynews.com/)\
[NRC Handelsblad](https://www.nrc.nl)\
[NT News](https://www.ntnews.com.au)\
[National Post](https://www.nationalpost.com)\
[Neue Zürcher Zeitung](https://www.nzz.ch)\
[New York Magazine](https://www.nymag.com)\
[New Zealand Herald](https://www.nzherald.co.nz)\
[Nikkei Asian Review](https://asia.nikkei.com)\
[Orange County Register](https://www.ocregister.com)\
[Orlando Sentinel](https://www.orlandosentinel.com)\
[PZC](https://www.pzc.nl)\
[Palo Alto Online](https://www.paloaltoonline.com)\
[Parool](https://www.parool.nl)\
[Postimees](https://www.postimees.ee)\
[Quartz](https://qz.com)\
[Quora](https://www.quora.com)\
[Quotidiani Gelocal](https://quotidiani.gelocal.it)\
[Republic.ru](https://republic.ru)\
[San Diego Union Tribune](https://www.sandiegouniontribune.com)\
[San Francisco Chronicle](https://www.sfchronicle.com)\
[Scientific American](https://www.scientificamerican.com)\
[Seeking Alpha](https://seekingalpha.com)\
[Slate](https://slate.com)\
[SOFREP](https://sofrep.com)\
[Statista](https://www.statista.com)\
[Star Tribune](https://www.startribune.com)\
[Stuff](https://www.stuff.co.nz)\
[SunSentinel](https://www.sun-sentinel.com)\
[Tech in Asia](https://www.techinasia.com)\
[Telegraaf](https://www.telegraaf.nl)\
[The Advertiser](https://www.adelaidenow.com.au)\
[The Advocate](https://www.theadvocate.com.au)\
[The Age](https://www.theage.com.au)\
[The American Interest](https://www.the-american-interest.com)\
[The Atlantic](https://www.theatlantic.com)\
[The Australian Financial Review](https://www.afr.com)\
[The Australian](https://www.theaustralian.com.au)\
[The Business Journals](https://www.bizjournals.com)\
[The Canberra Times](https://www.canberratimes.com.au)\
[The Courier](https://www.thecourier.com.au)\
[The Courier Mail](https://www.couriermail.com.au)\
[The Cut](https://www.thecut.com)\
[The Daily Telegraph](https://www.dailytelegraph.com.au)\
[The Diplomat](https://www.thediplomat.com)\
[The Economist](https://www.economist.com)\
[The Globe and Mail](https://www.theglobeandmail.com)\
[The Herald](https://www.theherald.com.au)\
[The Hindu](https://www.thehindu.com)\
[The Irish Times](https://www.irishtimes.com)\
[The Japan Times](https://www.japantimes.co.jp)\
[The Kansas City Star](https://www.kansascity.com)\
[The Mercury News](https://www.mercurynews.com)\
[The Mercury Tasmania](https://www.themercury.com.au)\
[The Morning Call](https://www.mcall.com)\
[The Nation](https://www.thenation.com)\
[The National](https://www.thenational.scot)\
[The New Statesman](https://www.newstatesman.com)\
[The New York Times](https://www.nytimes.com)\
[The New Yorker](https://www.newyorker.com)\
[The News-Gazette](https://www.news-gazette.com)\
[The Philadelphia Inquirer](https://www.inquirer.com)\
[The Saturday Paper](https://www.thesaturdaypaper.com.au)\
[The Seattle Times](https://www.seattletimes.com)\
[The Spectator Australia](https://www.spectator.com.au)\
[The Spectator](https://www.spectator.co.uk)\
[The Sydney Morning Herald](https://www.smh.com.au)\
[The Telegraph](https://www.telegraph.co.uk)\
[The Times](https://www.thetimes.co.uk)\
[The Toronto Star](https://www.thestar.com)\
[The Wall Street Journal](https://www.wsj.com)\
[The Washington Post](https://www.washingtonpost.com)\
[The Wrap](https://www.thewrap.com)\
[TheMarker](https://www.themarker.com)\
[Times Literary Supplement](https://www.the-tls.co.uk)\
[Towards Data Science](https://www.towardsdatascience.com)\
[Trouw](https://www.trouw.nl)\
[Tubantia](https://www.tubantia.nl)\
[Vanity Fair](https://www.vanityfair.com)\
[Vrij Nederland](https://www.vn.nl)\
[Vulture](https://www.vulture.com/)\
[Winston-Salem Journal](https://journalnow.com)\
[Wired](https://www.wired.com)\
[World Politics Review](https://www.worldpoliticsreview.com)

### Sites with limited number of free articles
The free article limit can normally be bypassed by removing cookies for the site.*

Install the Cookie Remover extension [for Google Chrome](https://chrome.google.com/webstore/detail/cookie-remover/kcgpggonjhmeaejebeoeomdlohicfhce) or [for Mozilla Firefox](https://addons.mozilla.org/en-US/firefox/addon/cookie-remover/). Please rate it 5 stars if you find it useful.

When coming across a paywall click the cookie icon to remove the cookies then refresh the page.

_*May not always succeed_

### New site requests
Only large or major sites will be considered. Usually premium articles cannot be bypassed as they are behind a hard paywall.

1. Install the uBlock Origin extension if it hasn't been installed already. See if you are still getting a paywall.
2. Check if using Cookie Remover ([Google Chrome version](https://chrome.google.com/webstore/detail/cookie-remover/kcgpggonjhmeaejebeoeomdlohicfhce) or [Mozilla Firefox version](https://addons.mozilla.org/en-US/firefox/addon/cookie-remover/)) can bypass the paywall. If not, continue to the next step.
3. First search [Issues](https://github.com/iamadamdev/bypass-paywalls-chrome/issues) to see if the site has been requested already.
4. Visit an article on the site you want to bypass the paywall for and copy the article title.
5. Open up a new incognito window (Ctrl+Shift+N on Chrome) or Private window (Ctrl+Shift+P on Firefox), and paste the article title into Google.
6. Click on the same article from the Google search results page.
7. If it loads without a paywall you can [submit a request](https://github.com/iamadamdev/bypass-paywalls-chrome/issues/new/choose) and replace the entire template text with the word "Confirmed". Otherwise please do not submit an issue as this extension cannot bypass it either.

### Troubleshooting
* This extension works best alongside uBlock Origin [for Google Chrome](https://chrome.google.com/webstore/detail/ublock-origin/cjpalhdlnbpafiamejdnhcphjbkeiagm) or [for Mozilla Firefox](https://addons.mozilla.org/en-US/firefox/addon/ublock-origin/).
* If a site doesn't work, try turning off uBlock and refreshing.
* Try clearing [cookies](https://chrome.google.com/webstore/detail/cookie-remover/kcgpggonjhmeaejebeoeomdlohicfhce).
* Make sure you're running the latest version of Bypass Paywalls.
* If a site is having problems try unchecking "\*General Paywall Bypass\*" in Options.
* If none of these work, you can submit an issue [here](https://github.com/iamadamdev/bypass-paywalls-chrome/issues/new/choose).

### Contributing - Pull Requests
PRs are welcome. 
1. If making a PR to add a new site, confirm your changes actually bypass the paywall.
2. At a minimum these files need to be updated: `README.md`, `manifest-ff.json`, `src/js/sites.js`, and possibly `src/js/background.js`, and/or `src/js/contentScript.js`.
3. Follow existing code-style and use camelCase.
4. Use [JavaScript Semi-Standard Style linter](https://github.com/standard/semistandard). Don't need to follow it exactly. There will be some errors (e.g., do not use it on `sites.js`).

### Show your support
* Follow me on Twitter [@iamadamdev](https://twitter.com/iamadamdev) for updates.
* I do not ask for donations, all I ask is that you star this repo.

### Disclaimer
* This software is provided for educational purposes only and
is provided "AS IS", without warranty of any kind, express or
implied, including but not limited to the warranties of merchantability,
fitness for a particular purpose and noninfringement. in no event shall the
authors or copyright holders be liable for any claim, damages or other
liability, whether in an action of contract, tort or otherwise, arising from,
out of or in connection with the software or the use or other dealings in the
software.
